@@ -171,11 +171,10 @@ use Email::MIME            ();
 use Email::MIME::Creator   ();
 use Email::Send            ();
 use prefork 'File::Type';
-use prefork 'File::Slurp';
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '2.05';
+	$VERSION = '2.06';
 }
 
 
@@ -458,9 +457,8 @@ sub attach_file {
 
 	# Support file names
 	} elsif ( defined $_[0] and -f $_[0] ) {
-		require File::Slurp;
 		$name = $_[0];
-		$body = File::Slurp::read_file( $_[0] );
+		$body = _slurp( $_[0] ) or return undef;
 
 	# That's it
 	} else {
@@ -474,6 +472,17 @@ sub attach_file {
 	$self->attach( $body, name => $name, filename => $name );
 }
 
+# Provide a simple _slurp implementation
+sub _slurp {
+	my $file = shift;
+	local $/ = undef;
+	local *SLURP;
+	open( SLURP, "<$file" ) or return undef;
+	my $source = <SLURP>;
+	close( SLURP ) or return undef;
+	\$source;
+}
+
 =pod
 
 =head2 using $drivername, @options
@@ -642,7 +651,7 @@ L<Email::MIME>, L<Email::Send>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2004 - 2007 Adam Kennedy.
+Copyright 2004 - 2008 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
